# air_piano

https://youtu.be/7KCmVyRpSCo

# How to install air-piano

Python3.7 or Python3.8 is recommended for running air-piano. 
In order to run air-piano, the following libraries must be installed.

$ pip install musicalbeeps

$ pip install mediapipe

$ pip install airpiano

# How to play air-piano

Moving thumb finger plays C5 note.

Moving index finger plays D5 note.

Middle finger plays E5 note.

Ring finger plays F5 note.

Little finger plays G5 note.

Moving thumb finger deeply plays A5 note.

Moving thumb finger deeply and index finger plays B5 note.

Moving thumb finger deeply and middle finger plays C6 note.

Moving thumb finger deeply and ring finger plays D6 note.

Moving thumb finger deeply and little finger plays E6 note.


$ airpiano
